@@ -85,6 +85,10 @@ sub run {
 
   my $maxtime = ((defined setting($job->action .'_timeout'))
     ? setting($job->action .'_timeout') : setting('workers')->{'timeout'});
+
+  # add some slack to timeout if the device is new and needs auth walkthrough
+  $maxtime += (40 * scalar @newuserconf) if ref $job->device and not $job->device->in_storage;
+
   if ($maxtime) {
     debug sprintf '%s: running with timeout %ss', $job->action, $maxtime;
     if (timeout_call($maxtime, $runner, ($self, $job))) {
